@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "mlscroll" "0.2.3"
+(define-package "mlscroll" "20250112.1440"
   "A scroll bar for the modeline."
   '((emacs "27.1"))
   :url "https://github.com/jdtsmith/mlscroll"
